---
title: <span class="badge builder"></span> RangeMap
---
# <span class="badge builder"></span> RangeMap

## Constructor

```python
RangeMap()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> dashboard.RangeMap
```

### <span class="badge object-method"></span> options

Range to match against and the result to apply when the value is within the range

```python
def options(options: cogbuilder.Builder[dashboard.DashboardRangeMapOptions]) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [RangeMap](./object-RangeMap.md)
